@@ -14,6 +14,7 @@ import (
 	"github.com/projectdiscovery/katana/pkg/utils"
 	errorutil "github.com/projectdiscovery/utils/errors"
 	fileutil "github.com/projectdiscovery/utils/file"
+	logutil "github.com/projectdiscovery/utils/log"
 	"gopkg.in/yaml.v3"
 )
 
@@ -112,7 +113,7 @@ func configureOutput(options *types.Options) {
 		gologger.DefaultLogger.SetMaxLevel(levels.LevelInfo)
 	}
 
-	// logutil.DisableDefaultLogger()
+	logutil.DisableDefaultLogger()
 }
 
 func initExampleFormFillConfig() error {
